"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const modify_chart_1 = require("../modify/modify-chart");
class ModifyChartHelper {
}
exports.default = ModifyChartHelper;
/**
 * Set chart data to modify default chart types.
 * See `__tests__/modify-existing-chart.test.js`
 */
ModifyChartHelper.setChartData = (data) => (element, chart, workbook) => {
    const slots = [];
    data.series.forEach((series, s) => {
        slots.push({
            index: s,
            series: series,
            targetCol: s + 1,
            type: 'defaultSeries',
        });
    });
    new modify_chart_1.ModifyChart(chart, workbook, data, slots).modify();
    // XmlHelper.dump(chart)
    // XmlHelper.dump(workbook.table)
};
/**
 * Set chart data to modify vertical line charts.
 * See `__tests__/modify-chart-vertical-lines.test.js`
 */
ModifyChartHelper.setChartVerticalLines = (data) => (element, chart, workbook) => {
    const slots = [];
    slots.push({
        label: `Y-Values`,
        mapData: (point, category) => category.y,
        targetCol: 1,
    });
    data.series.forEach((series, s) => {
        slots.push({
            index: s,
            series: series,
            targetCol: s + 2,
            type: 'xySeries',
        });
    });
    new modify_chart_1.ModifyChart(chart, workbook, data, slots).modify();
};
/**
 * Set chart data to modify bubble charts.
 * See `__tests__/modify-chart-bubbles.test.js`
 */
ModifyChartHelper.setChartBubbles = (data) => (element, chart, workbook) => {
    const slots = [];
    data.series.forEach((series, s) => {
        const colId = s * 3;
        slots.push({
            index: s,
            series: series,
            targetCol: colId + 1,
            type: 'customSeries',
            tag: 'c:xVal',
            mapData: (point) => point.x,
        });
        slots.push({
            label: `${series.label}-Y-Value`,
            index: s,
            series: series,
            targetCol: colId + 2,
            type: 'customSeries',
            tag: 'c:yVal',
            mapData: (point) => point.y,
            isStrRef: false,
        });
        slots.push({
            label: `${series.label}-Size`,
            index: s,
            series: series,
            targetCol: colId + 3,
            type: 'customSeries',
            tag: 'c:bubbleSize',
            mapData: (point) => point.size,
            isStrRef: false,
        });
    });
    new modify_chart_1.ModifyChart(chart, workbook, data, slots).modify();
    // XmlHelper.dump(chart)
};
//# sourceMappingURL=modify-chart-helper.js.map